@@ -35,15 +35,15 @@ pool = None
 
 re_userdict = re.compile('^(.+?)( [0-9]+)?( [a-z]+)?$', re.U)
 
-re_eng = re.compile('[a-zA-Z0-9]', re.U)
+re_eng = re.compile('[a-zA-Z0-9\uFF10-\uFF5A]', re.U)
 
 # \u4E00-\u9FD5a-zA-Z0-9+#&\._ : All non-space characters. Will be handled with re_han
 # \r\n|\s : whitespace characters. Will not be handled.
 # re_han_default = re.compile("([\u4E00-\u9FD5a-zA-Z0-9+#&\._%]+)", re.U)
 # Adding "-" symbol in re_han_default
-re_han_default = re.compile("([\u4E00-\u9FD5a-zA-Z0-9+#&\._%\-]+)", re.U)
+re_han_default = re.compile("([\u4E00-\u9FD5\uFF10-\uFF5Aa-zA-Z0-9+#&\._%]+)", re.U)
 
-re_skip_default = re.compile("(\r\n|\s)", re.U)
+re_skip_default = re.compile("(\r\n|\s|\u3000)", re.U)
 
 
 def setLogLevel(log_level):
